import React from 'react';
import ReactDOM from 'react-dom';
import { scaleLinear, scalePoint, extent } from 'd3';

import { useData } from './useData';
import { AxisLeft } from './AxisLeft';
import { AxisBottom } from './AxisBottom';
import { Marks } from './Marks';
import { Lines } from './Lines';

const width = 960;
const height = 500;
const margin = { top: 80, right: 80, bottom: 115, left: 120 };
const innerWidth = width - margin.left - margin.right;
const innerHeight = height - margin.top - margin.bottom;

const xAxisOffsetFactor = 8;
const yAxisOffsetFactor = 20;

const color = { before: '#66c2a5', after: '#fc8d62' };

const App = () => {
  const data = useData();

  
  // 로딩 창 
  
  if (!data) {
    return <pre>Loading...</pre>;
  }

  const xValue = (d) => d.id;
  const yValue1 = (d) => d.alc_begin;
  const yValue2 = (d) => d.alc_end;

  const xLabel = 'Patient ID';

  const yScaleExtent = extent(data.map(yValue1).concat(data.map(yValue2)));
  const yScale = scaleLinear()
    .domain(yScaleExtent)
    .range([innerHeight, 0])
    .nice();

  const xScale = scalePoint()
    .domain(data.map(xValue))
    .range([0, innerWidth])
    .padding(0.2);

  return (
    <div className="App">
      <svg width={width} height={height}>
        <g transform={`translate(${margin.left}, ${margin.top})`}>
          <AxisLeft
            yScale={yScale}
            innerWidth={innerWidth}
            yAxisOffsetFactor={yAxisOffsetFactor}
          />

          <AxisBottom
            xScale={xScale}
            innerHeight={innerHeight}
            xAxisOffsetFactor={xAxisOffsetFactor}
          />

          <text
            className="axis-bottom"
            x={innerWidth / 2}
            y={innerHeight + 9 * xAxisOffsetFactor}
          >
            {xLabel}
          </text>

          <Lines
            data={data}
            xScale={xScale}
            xValue={xValue}
            yScale={yScale}
            yValue1={yValue1}
            yValue2={yValue2}
          />

          <Marks // begin
            data={data}
            xScale={xScale}
            xValue={xValue}
            yScale={yScale}
            yValue={yValue1}
            color={color.before}
          />

          <Marks // end
            data={data}
            xScale={xScale}
            xValue={xValue}
            yScale={yScale}
            yValue={yValue2}
            color={color.after}
          />
        </g>
      </svg>
      <h2
        className="heading"
        style={{ left: margin.left, top: margin.top / 6 }}
      >
        
        <span style={{ color: color.before }}> Before </span> vs
        <span style={{ color: color.after }}> After </span> 
      </h2>
    </div>
  );
};

ReactDOM.render(<App />, document.getElementById('roo